@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -20,23 +20,31 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
+import logging
 from urllib.error import HTTPError
 
-from allauth.account.models import EmailAddress
 from django.conf import settings
-from django_mailman3.lib.cache import cache
+from django.core.cache import cache
 from django.db import IntegrityError
-from mailmanclient import Client as MailmanClient, MailmanConnectionError
 
-import logging
+from allauth.account.models import EmailAddress
+from mailmanclient import Client as MailmanClient
+from mailmanclient import MailmanConnectionError
+
+
 logger = logging.getLogger(__name__)
 
 
-def get_mailman_client():
+def get_mailman_client(api_version='3.0'):
+    """Return an instance of Mailman Client.
+
+    :param api_version: The API version for Mailman Core to use.
+    :type api_version: string
+    :returns: An instance of :class:`mailmanclient.Client`
+    """
     # easier to patch during unit tests
     client = MailmanClient(
-        '%s/3.0' %
-        settings.MAILMAN_REST_API_URL,
+        '{}/{}'.format(settings.MAILMAN_REST_API_URL, api_version),
         settings.MAILMAN_REST_API_USER,
         settings.MAILMAN_REST_API_PASS)
     return client
