@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2018 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -21,9 +21,8 @@
 #
 
 
+from django.core.paginator import EmptyPage, InvalidPage, Paginator
 from django.http import Http404
-from django.core.paginator import (
-    Paginator, EmptyPage, InvalidPage)
 from django.utils.functional import cached_property
 
 
